@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "firstly-search" "0.1.4"
+(define-package "firstly-search" "20250904.5"
   "Search with any key: Dired, Package, Buffer menu modes."
   '((emacs  "29.1")
     (compat "30.1"))
   :url "https://codeberg.org/Anoncheg/firstly-search"
-  :commit "1b5555f2de25bddb7d57d2aa8144f59759e48dac"
-  :revdesc "1b5555f2de25"
+  :commit "509cb483e68caf8e6ecd0f171330b91eff430583"
+  :revdesc "509cb483e68c"
   :keywords '("matching" "isearch" "navigation" "dired" "packagemenu")
   :authors '((nil . "github.com/Anoncheg1,codeberg.org/Anoncheg"))
   :maintainers '((nil . "github.com/Anoncheg1,codeberg.org/Anoncheg")))
